ParallelSpec
==================================

.. currentmodule:: alfred3_interact.spec

.. autoclass:: ParallelSpec
   :show-inheritance:




   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
      :toctree:




      ~ParallelSpec.full







   .. rubric:: Attributes

   .. autosummary::
      :template: autosummary/attribute.rst
      :toctree:


         ~ParallelSpec.group_type
         ~ParallelSpec.pattern
         ~ParallelSpec.quota
